@@ -5,7 +5,7 @@ set -eu
 # NOTE(pas-ha) the above exports some useful variables like
 # $PYTHON , $PIP and $VENV depending on venv install or not
 
-DEFAULT_PIP_ANSIBLE='>=2.9,<2.10'
+DEFAULT_PIP_ANSIBLE='>=2.9,<2.11'
 
 ANSIBLE_COLLECTIONS_REQ=${ANSIBLE_COLLECTIONS_REQ:-$(dirname $0)/../ansible-collections-requirements.yml}
 ANSIBLE_COLLECTION_SOURCE_PATH=
@@ -19,24 +19,18 @@ ANSIBLE_SOURCE_PATH=${ANSIBLE_SOURCE_PATH:-ansible${ANSIBLE_PIP_VERSION}}
 BIFROST_COLLECTIONS_PATHS=${ANSIBLE_COLLECTIONS_PATHS:-}
 PLAYBOOKS_LIBRARY_PATH=$(dirname $0)/../playbooks/library
 
-
-if [[ -n "${VENV-}" ]]; then
-    ${PIP} install "${ANSIBLE_SOURCE_PATH}"
-    ANSIBLE=${VENV}/bin/ansible
-    ANSIBLE_GALAXY=${VENV}/bin/ansible-galaxy
-    if [[ -z $BIFROST_COLLECTIONS_PATHS ]]; then
-        echo  "Setting ANSIBLE_COLLECTIONS_PATHS to virtualenv"
-        export ANSIBLE_COLLECTIONS_PATHS=${VENV}/collections
-        BIFROST_COLLECTIONS_PATHS=$ANSIBLE_COLLECTIONS_PATHS
-    fi
-    if [[ -n "$ANSIBLE_COLLECTION_SOURCE_PATH" ]]; then
-        mkdir -p "$BIFROST_COLLECTIONS_PATHS/ansible_collections/openstack"
-        ln -s "$ANSIBLE_COLLECTION_SOURCE_PATH" "$BIFROST_COLLECTIONS_PATHS/ansible_collections/openstack/cloud"
-    fi
-else
-    ${PIP} install --user --upgrade "${ANSIBLE_SOURCE_PATH}"
-    ANSIBLE=${HOME}/.local/bin/ansible
-    ANSIBLE_GALAXY=${HOME}/.local/bin/ansible-galaxy
+echo "Installing/upgrading Ansible"
+${PIP} install "${ANSIBLE_SOURCE_PATH}"
+ANSIBLE=${VENV}/bin/ansible
+ANSIBLE_GALAXY=${VENV}/bin/ansible-galaxy
+if [[ -z $BIFROST_COLLECTIONS_PATHS ]]; then
+    echo  "Setting ANSIBLE_COLLECTIONS_PATHS to virtualenv"
+    export ANSIBLE_COLLECTIONS_PATHS=${VENV}/collections
+    BIFROST_COLLECTIONS_PATHS=$ANSIBLE_COLLECTIONS_PATHS
+fi
+if [[ -n "$ANSIBLE_COLLECTION_SOURCE_PATH" ]]; then
+    mkdir -p "$BIFROST_COLLECTIONS_PATHS/ansible_collections/openstack"
+    ln -s "$ANSIBLE_COLLECTION_SOURCE_PATH" "$BIFROST_COLLECTIONS_PATHS/ansible_collections/openstack/cloud"
 fi
 
 # NOTE(pas-ha) the following is a temporary workaround for third-party CI
@@ -69,15 +63,10 @@ if [ ! -e "$(dirname $0)/../playbooks/collections" ]; then
     ln -s ${ANSIBLE_COLLECTIONS_PATHS} "$(dirname $0)/../playbooks/collections"
 fi
 
-echo
-echo "To use bifrost, do"
-
-if [[ -n "${VENV-}" ]]; then
+if [[ "${BIFROST_HIDE_PROMPT:-false}" != true ]]; then
+    echo
+    echo "To use bifrost, do"
     echo "source ${VENV}/bin/activate"
-else
-    echo "Prepend ~/.local/bin to your PATH if it is not that way already.."
-    echo ".. or use full path to local Ansible at ~/.local/bin/ansible-playbook"
+    echo "Then run playbooks as normal."
+    echo
 fi
-echo "source env-vars"
-echo "Then run playbooks as normal."
-echo
